---
categories: [it, program]
tags: [VSCode, FAQ]
lang: ru
---

# Title of book

> Line 1.
>
> Line 2.
>
> -- _Name Surname, Title of book_

---

> Line 3.
>
> Line 4.
>
> -- _Name Surname, Modified title of book_
